# paraphrase-metrics

Metrics for better understanding of Paraphrases

`pip install paraphrase-metrics`

## About

A python package containing implementations of word position deviation (WPD) and lexical deviation (LD) proposed in "Towards Better Characterization of Paraphrases" (ACL 2022). 

For a simple demo, please see [demo.ipynb](demo.ipynb).

## Paper

The full code associated with the ACL 2022 paper "Towards Better Characterization of Paraphrases" can be found in the `./paper/` folder. 